/*==========================================================================*/
/* SEED reader     |            find_type43               |  station header */
/*==========================================================================*/
/*
	Name:		find_type43
	Purpose:	print channel poles and zeroes response table to standard 
				output
	Usage:		void find_type43 ();
				find_type43 ();
	Input:		none - uses information in globally-available structure
	Output:		none
	Externals:	type43_head - 1st entry in table; defined in structures.h, 
					allocated in globals.h
	Warnings:	none
	Errors:		none
	Called by:	print_response
	Calls to:	none
	Algorithm:	print the contents of the structure to the standard output.
	Notes:		The structure is a linked list; type43_head is the first member
				of the list
	Problems:	none known
	References:	Halbert et al, 1988; see main routine
	Language:	C, hopefully ANSI standard
	Author:		Dennis O'Neill
	Revisions:
				02/16/94	CL changed string formated output to protect against null
							pointers
*/

#include "rdseed.h"
#include "resp_defs.h"

int find_type43(fp, code)
FILE *fp;
int code;
{
	struct type43 *type43;					    /* looping vbl */
	int i;										/* counter */
	char *blkt_id="B043";						/* blockette id string */

	for (type43 = type43_head; type43 != NULL; type43 = type43->next)
	{
		if (type43->response_code == code)
		{
			if (fp == NULL) break;

			save_myfprintf (fp,"%s+               +-----------------------",COM_STRT);
			save_myfprintf (fp,"---------------------+                +\n");
			save_myfprintf (fp,"%s+               |   Response (Poles & Zeros), %5s ch %3s",COM_STRT,
					 current_station->station, current_channel->channel);
			save_myfprintf (fp,"   |                +\n");
			save_myfprintf (fp,"%s+               +-----------------------",COM_STRT);
			save_myfprintf (fp,"---------------------+                +\n");
			save_myfprintf (fp,"%s\n",COM_STRT);

			save_myfprintf (fp,"%s%s%2.2d     Response type:                ",blkt_id,FLD_PREF,5);
			switch (type43->response_type)
			{
			  case 'A' : save_myfprintf(fp,"         A [Laplace Transform (Rad/sec)]\n"); break;
			  case 'B' : save_myfprintf(fp,"         B [Analog (Hz)]\n"); break;
			  case 'C' : save_myfprintf(fp,"         C [Composite]\n"); break;
			  case 'D' : save_myfprintf(fp,"         D [Digital (Z-transform)]\n"); break;
			  default  : save_myfprintf(fp,"         %c\n",type43->response_type ? type43->response_type : ' '); break;
			}
			save_myfprintf (fp,"%s%s%2.2d     Response in units lookup:              ",
				blkt_id,FLD_PREF,6);

			find_type34(fp,type43->input_units_code);

			save_myfprintf (fp,"%s%s%2.2d     Response out units lookup:             ",
				blkt_id,FLD_PREF,7);

			find_type34(fp,type43->output_units_code);

			save_myfprintf (fp,"%s%s%2.2d     A0 normalization factor:               %G\n",
				blkt_id,FLD_PREF,8,type43->ao_norm);

			save_myfprintf (fp,"%s%s%2.2d     Normalization frequency:               %G\n",
				blkt_id,FLD_PREF,9,type43->norm_freq);

			save_myfprintf (fp,"%s%s%2.2d     Number of zeroes:                      %d\n",
				blkt_id,FLD_PREF,10,type43->number_zeroes);

			save_myfprintf (fp,"%s%s%2.2d     Number of poles:                       %d\n",
				blkt_id,FLD_PREF,15,type43->number_poles);

			save_myfprintf (fp,"%sComplex zeroes:\n",COM_STRT);

			save_myfprintf (fp,"%s  i  real          imag          real_error    imag_error\n",
					 COM_STRT);
			for (i = 0; i < type43->number_zeroes; i++)
				save_myfprintf (fp,"%s%s%2.2d-%2.2d  %3d % E % E % E % E\n",
						 blkt_id,FLD_PREF,11,14,i, 
						 type43->zero[i].real, 
						 type43->zero[i].imag,
						 type43->zero[i].real_error, 
						 type43->zero[i].imag_error);

			save_myfprintf (fp,"%sComplex poles:\n",COM_STRT);

			save_myfprintf (fp,"%s  i  real          imag          real_error    imag_error\n",
					 COM_STRT);

			for (i = 0; i < type43->number_poles; i++)
				save_myfprintf (fp,"%s%s%2.2d-%2.2d  %3d % E % E % E % E\n",
						 blkt_id,FLD_PREF,16,19,i, 
						 type43->pole[i].real, 
						 type43->pole[i].imag,
						 type43->pole[i].real_error, 
						 type43->pole[i].imag_error);
			save_myfprintf (fp,"%s\n",COM_STRT);
			break;
		}
	}
	if (type43 == NULL) return(0); else return(1);
}

int old_find_type43(fp, code)
FILE *fp;
int code;
{
	struct type43 *type43;					/* looping vbl */
	int i;										/* counter */

	for (type43 = type43_head; type43 != NULL; type43 = type43->next)
	{
		if (type43->response_code == code)
		{
			if (fp == NULL) break;

			save_myfprintf (fp,"B043\n");
			save_myfprintf (fp,"Response lookup code:                  %d\n",
				type43->response_code);

			save_myfprintf (fp,"Response name:                         %s\n",
						type43->name ? type43->name : "(null)");

			save_myfprintf (fp,"Response type:                         %c\n",
				type43->response_type);

			save_myfprintf (fp,"Response in units lookup: %4d         ",
				type43->input_units_code);

			find_type34(fp,type43->input_units_code);

			save_myfprintf (fp,"Response out units lookup: %4d        ",
				type43->output_units_code);

			find_type34(fp,type43->output_units_code);

			save_myfprintf (fp,"AO normalization factor:               %G\n",
				type43->ao_norm);

			save_myfprintf (fp,"Normalization frequency:               %G\n",
				type43->norm_freq);

			save_myfprintf (fp,"Number of zeroes:                      %d\n",
				type43->number_zeroes);

			save_myfprintf (fp,"Number of poles:                       %d\n",
				type43->number_poles);

			save_myfprintf (fp,"Complex zeroes:\n");

			save_myfprintf (fp,"  i  real          imag          real_error    imag_error\n");
			for (i = 0; i < type43->number_zeroes; i++)
				save_myfprintf (fp,"%3d % E % E % E % E\n", i, 
				type43->zero[i].real, 
				type43->zero[i].imag,
				type43->zero[i].real_error, 
				type43->zero[i].imag_error);

			save_myfprintf (fp,"Complex poles:\n");

			save_myfprintf (fp,"  i  real          imag          real_error    imag_error\n");

			for (i = 0; i < type43->number_poles; i++)
				save_myfprintf (fp,"%3d % E % E % E % E\n", i, 
				type43->pole[i].real, 
				type43->pole[i].imag,
				type43->pole[i].real_error, 
				type43->pole[i].imag_error);
			save_myfprintf (fp,"\n");
			break;
		}
	}
	if (type43 == NULL) return(0); else return(1);
}
