/**
 * test_chk_time
 *
 * unit test the chk_time function in Decoders/process_data.c
 *
 * Robert Casey -- May 2014
 *
 */
#include <stdlib.h>
#include <unistd.h>
#include <ctype.h>
#include <rdseed.h>
#include "structures.h"

/*
 * return 1 if OK
 * return 0 if not OK
 */

/* Global vars to fit rdseed implementation */
extern int	start_time_count;		/* count of start time fields */
extern struct time	*start_time_point;	/* list of start time pointers */
extern int	end_time_count;			/* count of end times */
extern struct time	*end_time_point;	/* list of end time pointers */

/* this test checks to see how rudimentary time values are
 * accepted by the function in the absence of any global time
 * vars to compare to
 */
int test_chk_time_001() {

	int return_code = 0;

	struct time blk_start = {
		.year=1900,
		.day=1,
		.hour=0,
		.minute=0,
		.second=0,
		.fracsec=0
	};

	struct time blk_end = {
		.year=2599,
		.day=365,
		.hour=23,
		.minute=59,
		.second=59,
		.fracsec=9999
	};

	/* process_data.c: chk_time(struct time blk_start, struct time blk_end) */
	return_code = chk_time(blk_start,blk_end);

	return return_code;
}

/* this test checks to see how rudimentary time values are
 * accepted by the function with the instantiation of a single
 * start and end time global var set.
 */
int test_chk_time_002() {

	int return_code = 0;
	start_time_count = 1;
	end_time_count = 1;
	start_time_point = (struct time *) malloc(sizeof (struct time));
	end_time_point = (struct time *) malloc(sizeof (struct time));

	start_time_point->year=2000;
	start_time_point->day=1;
	start_time_point->hour=0;
	start_time_point->minute=0;
	start_time_point->second=0;
	start_time_point->fracsec=0;

	end_time_point->year=2001;
	end_time_point->day=145;
	end_time_point->hour=3;
	end_time_point->minute=56;
	end_time_point->second=22;
	end_time_point->fracsec=492;

	struct time blk_start = {
		.year=1900,
		.day=1,
		.hour=0,
		.minute=0,
		.second=0,
		.fracsec=0
	};

	struct time blk_end = {
		.year=2599,
		.day=365,
		.hour=23,
		.minute=59,
		.second=59,
		.fracsec=9999
	};

	/* process_data.c: chk_time(struct time blk_start, struct time blk_end) */
	return_code = chk_time(blk_start,blk_end);

	/* we expect a 0 to be returned if OK based on the time params */
	return (return_code == 0);

}


/* this test checks to see if containment of a time fit is detected
 */
int test_chk_time_003() {

	int return_code = 0;
	start_time_count = 1;
	end_time_count = 1;
	start_time_point = (struct time *) malloc(sizeof (struct time));
	end_time_point = (struct time *) malloc(sizeof (struct time));

	start_time_point->year=2000;
	start_time_point->day=1;
	start_time_point->hour=0;
	start_time_point->minute=0;
	start_time_point->second=0;
	start_time_point->fracsec=0;

	end_time_point->year=2001;
	end_time_point->day=145;
	end_time_point->hour=3;
	end_time_point->minute=56;
	end_time_point->second=22;
	end_time_point->fracsec=492;

	struct time blk_start = {
		.year=2000,
		.day=1,
		.hour=0,
		.minute=0,
		.second=0,
		.fracsec=0
	};

	struct time blk_end = {
		.year=2000,
		.day=365,
		.hour=23,
		.minute=59,
		.second=59,
		.fracsec=9999
	};

	/* process_data.c: chk_time(struct time blk_start, struct time blk_end) */
	return_code = chk_time(blk_start,blk_end);

	return return_code;

}


/*
 *  this test checks to see if a time fit is detected among multiple epochs
 */
int test_chk_time_004() {

	int return_code = 0;
	start_time_count = 3;  /* we will use three epochs */
	end_time_count = 3;    /* the end times will be properly terminated */
	start_time_point = (struct time *) malloc(3*sizeof (struct time));
	end_time_point = (struct time *) malloc(3*sizeof (struct time));

	/* --------------------------- */
	start_time_point[0].year=1998;
	start_time_point[0].day=4;
	start_time_point[0].hour=23;
	start_time_point[0].minute=34;
	start_time_point[0].second=9;
	start_time_point[0].fracsec=0;

	end_time_point[0].year=2000;
	end_time_point[0].day=78;
	end_time_point[0].hour=23;
	end_time_point[0].minute=59;
	end_time_point[0].second=59;
	end_time_point[0].fracsec=9999;

	/* --------------------------- */
	start_time_point[1].year=2000;
	start_time_point[1].day=79;
	start_time_point[1].hour=0;
	start_time_point[1].minute=0;
	start_time_point[1].second=0;
	start_time_point[1].fracsec=0;

	end_time_point[1].year=2001;
	end_time_point[1].day=145;
	end_time_point[1].hour=3;
	end_time_point[1].minute=56;
	end_time_point[1].second=22;
	end_time_point[1].fracsec=492;

	/* --------------------------- */
	start_time_point[2].year=2001;
	start_time_point[2].day=145;
	start_time_point[2].hour=3;
	start_time_point[2].minute=57;
	start_time_point[2].second=30;
	start_time_point[2].fracsec=0;

	end_time_point[2].year=2005;
	end_time_point[2].day=1;
	end_time_point[2].hour=0;
	end_time_point[2].minute=0;
	end_time_point[2].second=0;
	end_time_point[2].fracsec=0;

	struct time blk_start = {
		.year=2000,
		.day=100,
		.hour=11,
		.minute=0,
		.second=0,
		.fracsec=0
	};

	struct time blk_end = {
		.year=2000,
		.day=365,
		.hour=23,
		.minute=59,
		.second=59,
		.fracsec=9999
	};

	/* process_data.c: chk_time(struct time blk_start, struct time blk_end) */
	return_code = chk_time(blk_start,blk_end);

	return return_code;

}




/*
 *  this test checks for a time fit where an epoch is non-terminated
 */
int test_chk_time_005() {

	int return_code = 0;
	start_time_count = 3;  /* we will use three epochs */
	end_time_count = 2;    /* the last end time will be absent */
	start_time_point = (struct time *) malloc(start_time_count*sizeof (struct time));
	end_time_point = (struct time *) malloc(end_time_count*sizeof (struct time));

	/* --------------------------- */
	start_time_point[0].year=1998;
	start_time_point[0].day=4;
	start_time_point[0].hour=23;
	start_time_point[0].minute=34;
	start_time_point[0].second=9;
	start_time_point[0].fracsec=0;

	end_time_point[0].year=2000;
	end_time_point[0].day=78;
	end_time_point[0].hour=23;
	end_time_point[0].minute=59;
	end_time_point[0].second=59;
	end_time_point[0].fracsec=9999;

	/* --------------------------- */
	start_time_point[1].year=2000;
	start_time_point[1].day=79;
	start_time_point[1].hour=0;
	start_time_point[1].minute=0;
	start_time_point[1].second=0;
	start_time_point[1].fracsec=0;

	end_time_point[1].year=2001;
	end_time_point[1].day=145;
	end_time_point[1].hour=3;
	end_time_point[1].minute=56;
	end_time_point[1].second=22;
	end_time_point[1].fracsec=492;

	/* --------------------------- */
	start_time_point[2].year=2001;
	start_time_point[2].day=145;
	start_time_point[2].hour=3;
	start_time_point[2].minute=57;
	start_time_point[2].second=30;
	start_time_point[2].fracsec=0;
	/* start time only -- implying an open epoch */


	struct time blk_start = {
		.year=2005,
		.day=100,
		.hour=11,
		.minute=0,
		.second=0,
		.fracsec=0
	};

	struct time blk_end = {
		.year=2005,
		.day=365,
		.hour=23,
		.minute=59,
		.second=59,
		.fracsec=9999
	};

	/* process_data.c: chk_time(struct time blk_start, struct time blk_end) */
	return_code = chk_time(blk_start,blk_end);

	return return_code;

}

/*
 *  this test checks using times from Bug#1218, which used to show a bad end value
 */
int test_chk_time_006() {

	int return_code = 0;
	start_time_count = 2;
	end_time_count = 2;
	start_time_point = (struct time *) malloc(start_time_count*sizeof (struct time));
	end_time_point = (struct time *) malloc(end_time_count*sizeof (struct time));

	/* --------------------------- */
	start_time_point[0].year=1995;
	start_time_point[0].day=219;
	start_time_point[0].hour=0;
	start_time_point[0].minute=0;
	start_time_point[0].second=0;
	start_time_point[0].fracsec=0;

	end_time_point[0].year=1996;
	end_time_point[0].day=29;
	end_time_point[0].hour=0;
	end_time_point[0].minute=0;
	end_time_point[0].second=0;
	end_time_point[0].fracsec=0;

	/* --------------------------- */
	start_time_point[1].year=1996;
	start_time_point[1].day=29;
	start_time_point[1].hour=0;
	start_time_point[1].minute=0;
	start_time_point[1].second=0;
	start_time_point[1].fracsec=0;

	end_time_point[1].year=1996;
	end_time_point[1].day=33;
	end_time_point[1].hour=0;
	end_time_point[1].minute=0;
	end_time_point[1].second=0;
	end_time_point[1].fracsec=0;

	struct time blk_start = {
		.year=1996,
		.day=30,
		.hour=0,
		.minute=0,
		.second=0,
		.fracsec=0
	};

	struct time blk_end = {
		.year=1996,
		.day=33,
		.hour=0,
		.minute=0,
		.second=0,
		.fracsec=0
	};

	/* process_data.c: chk_time(struct time blk_start, struct time blk_end) */
	return_code = chk_time(blk_start,blk_end);

	return return_code;

}


/*
 *  this test checks using times from Bug#1218, but we'll test a time that
 *  bridges two epochs....we should still get a match
 */
int test_chk_time_007() {

	int return_code = 0;
	start_time_count = 2;
	end_time_count = 2;
	start_time_point = (struct time *) malloc(start_time_count*sizeof (struct time));
	end_time_point = (struct time *) malloc(end_time_count*sizeof (struct time));

	/* --------------------------- */
	start_time_point[0].year=1995;
	start_time_point[0].day=219;
	start_time_point[0].hour=0;
	start_time_point[0].minute=0;
	start_time_point[0].second=0;
	start_time_point[0].fracsec=0;

	end_time_point[0].year=1996;
	end_time_point[0].day=29;
	end_time_point[0].hour=0;
	end_time_point[0].minute=0;
	end_time_point[0].second=0;
	end_time_point[0].fracsec=0;

	/* --------------------------- */
	start_time_point[1].year=1996;
	start_time_point[1].day=29;
	start_time_point[1].hour=0;
	start_time_point[1].minute=0;
	start_time_point[1].second=0;
	start_time_point[1].fracsec=0;

	end_time_point[1].year=1996;
	end_time_point[1].day=33;
	end_time_point[1].hour=0;
	end_time_point[1].minute=0;
	end_time_point[1].second=0;
	end_time_point[1].fracsec=0;

	struct time blk_start = {
		.year=1996,
		.day=1,
		.hour=0,
		.minute=0,
		.second=0,
		.fracsec=0
	};

	struct time blk_end = {
		.year=1996,
		.day=32,
		.hour=0,
		.minute=0,
		.second=0,
		.fracsec=0
	};

	/* process_data.c: chk_time(struct time blk_start, struct time blk_end) */
	return_code = chk_time(blk_start,blk_end);

	return return_code;

}
