/*===========================================================================*/
/* SEED reader     |            print_type48               |  station header */
/*===========================================================================*/
/*
	Name:		print_type48
	Purpose:	print the channel sensitivity table to standard output
	Usage:		void print_type48 ();
				print_type48 ();
	Input:		none - uses information in globally-available structure
	Output:		none
	Externals:	type48_head - 1st entry in table; defined in structures.h, 
					allocated in globals.h
	Warnings:	none
	Errors:		none
	Called by:	print_response
	Calls to:	none
	Algorithm:	print the contents of the structure to the standard output.
	Notes:		The structure is a linked list; type48_head is the first member
				of the list
	Problems:	none known
	References:	Halbert et al, 1988; see main routine
	Language:	C, hopefully ANSI standard
	Author:		Sue Schoch
	Revisions:
                02/17/93  CL    nullpointer protect save_myfprintfs

*/

#include "rdseed.h"
#include "resp_defs.h"

int find_type48(fp, code)
FILE *fp;
int code;
{
	struct type48 *type48;						/* looping vbl */
	int i;										/* counter */
	char *blkt_id="B048";						/* blockette id string */

	for (type48 = type48_head; type48 != NULL; type48 = type48->next)
	{
	
		if (type48->response_code == code)
		{
			if (fp == NULL) break;

			save_myfprintf (fp,"%s+                  +--------------------", COM_STRT);
			save_myfprintf (fp,"-------------------+                  +\n");
			save_myfprintf (fp,"%s+                  |   Channel Sensitivity, %5s ch %3s   ",
					 COM_STRT,current_station->station,current_channel->channel);
			save_myfprintf (fp,"|                  +\n");
			save_myfprintf (fp,"%s+                  +--------------------", COM_STRT);
			save_myfprintf (fp,"-------------------+                  +\n");
			save_myfprintf (fp,"%s\n", COM_STRT);

			save_myfprintf (fp,"%s%s%2.2d     Sensitivity:                           %E\n",
				blkt_id,FLD_PREF,5,type48->sensitivity);
			save_myfprintf (fp,"%s%s%2.2d     Frequency of sensitivity:              %E\n",
				blkt_id,FLD_PREF,6,type48->frequency);
			save_myfprintf (fp,"%s%s%2.2d     Number of calibrations:                %d\n",
				blkt_id,FLD_PREF,7,type48->number_calibrations);
			if (type48->number_calibrations != 0)
			{
				save_myfprintf (fp,"%sCalibrations:\n",COM_STRT);
				save_myfprintf (fp,"%s  i, sensitivity,  frequency,   time of calibration\n",
						 COM_STRT);
				for (i = 0; i < type48->number_calibrations; i++)
					save_myfprintf (fp,"%s%s%2.2d-%2.2d  %3d % E % E %s\n",
					   blkt_id,FLD_PREF,8,10,i, 
					   type48->calibration[i].sensitivity, 
					   type48->calibration[i].frequency,
					   type48->calibration[i].time ? type48->calibration[i].time :
							     "(null)");
			}
			save_myfprintf (fp,"%s\n",COM_STRT);
			break;
		}
	}
	if (type48 == NULL) return(0); else return(1);
}

int old_find_type48(fp, code)
FILE *fp;
int code;
{
	struct type48 *type48;							/* looping vbl */
	int i;										/* counter */

	for (type48 = type48_head; type48 != NULL; type48 = type48->next)
	{
		if (type48->response_code == code)
		{
			if (fp == NULL) break;

			save_myfprintf (fp,"B048\n");
			save_myfprintf (fp,"Response Lookup Code:                  %d\n",
				type48->response_code);
			save_myfprintf (fp,"Response name:                         %s\n",
				type48->name ? type48->name : "(null)");
			save_myfprintf (fp,"Sensitivity:                           %E\n",
				type48->sensitivity);
			save_myfprintf (fp,"Frequency of sensitivity:              %E\n",
				type48->frequency);
			save_myfprintf (fp,"Number of calibrations:                %d\n",
				type48->number_calibrations);
			if (type48->number_calibrations != 0)
			{
				save_myfprintf (fp,"Calibrations:\n");
				save_myfprintf (fp,"  i, sensitivity,  frequency,   time of calibration\n");
				for (i = 0; i < type48->number_calibrations; i++)
					save_myfprintf (fp,"%3d % E % E %s\n", i, 
					type48->calibration[i].sensitivity, 
					type48->calibration[i].frequency,
					type48->calibration[i].time ? type48->calibration[i].time :
									 "(null)");
			}
			save_myfprintf (fp,"\n");
			break;
		}
	}
	if (type48 == NULL) return(0); else return(1);
}
