/*===========================================================================*/
/* SEED reader     |             find_type42               |  station header */
/*===========================================================================*/
/*
	Name:		find_type42
	Purpose:	print the channel coefficients response table to standard 
				output
	Usage:		void find_type42 ();
				find_type42 ();
	Input:		none - uses information in globally-available structure
	Output:		none
	Externals:	type42_head - 1st entry in table; defined in structures.h, 
					allocated in globals.h
	Warnings:	none
	Errors:		none
	Called by:	print_response
	Calls to:	none
	Algorithm:	print the contents of the structure to the standard output.
	Notes:		The structure is a linked list; type42_head is the first member
				of the list
	Problems:	none known
	References:	Halbert et al, 1988; see main routine
	Language:	C, hopefully ANSI standard
	Author:		Stephane Zuzlewski
*/

#include "rdseed.h"
#include "resp_defs.h"

int
find_type42(fp, code)
FILE *fp;
int code;
{
	struct type42 *type42;						/* looping vbl */
	int i;								/* counter */
	char *blkt_id="B042";						/* blockette id string */

	for (type42 = type42_head; type42 != NULL; type42 = type42->next)
	{
		if (type42->response_code == code)
		{
			if (fp == NULL) break;

			save_myfprintf (fp,"%s+              +------------------------",COM_STRT);
			save_myfprintf (fp,"---------------+                      +\n");
			save_myfprintf (fp,"%s+              |   Polynomial response, %5s ch %3s",COM_STRT,
					 current_station->station, current_channel->channel);
			save_myfprintf (fp,"   |                      +\n");
			save_myfprintf (fp,"%s+              +------------------------",COM_STRT);
			save_myfprintf (fp,"---------------+                      +\n");
			save_myfprintf (fp,"%s\n",COM_STRT);

			save_myfprintf (fp, "%s%s%2.2d     Transfer function type:       ",blkt_id,FLD_PREF,5);
				switch (type42->transfer_fct_type)
				{
				case 'A' : save_myfprintf(fp,"         A [Laplace Transform (Rad/sec)]\n"); break;
				case 'B' : save_myfprintf(fp,"         B [Analog (Hz)]\n"); break;
				case 'C' : save_myfprintf(fp,"         C [Composite]\n"); break;
				case 'D' : save_myfprintf(fp,"         D [Digital (Z-transform)]\n"); break;
				case 'P' : save_myfprintf(fp,"         P [Polynomial]\n"); break;
				/* default  : save_myfprintf(fp,"         %s\n",type42->transfer_fct_type ? (char *)type42->transfer_fct_type : "(null)"); break;
				*/
					default  : save_myfprintf(fp,"         %c\n",
						type42->transfer_fct_type); 
						break;
				}

			save_myfprintf(fp,"%s%s%2.2d     Response in units lookup:              ",
					blkt_id,FLD_PREF,6);
			find_type34(fp, type42->input_units_code);

			save_myfprintf(fp,"%s%s%2.2d     Response out units lookup:             ",
					blkt_id,FLD_PREF,7);
			find_type34(fp, type42->output_units_code);

			save_myfprintf(fp,"%s%s%2.2d     Polynomial Approximation Type:         ", blkt_id,FLD_PREF,8);
				switch (type42->poly_approx_type)
				{
				case 'M' : save_myfprintf(fp,"M [MacLaurin]\n"); break;
				default  : save_myfprintf(fp,"%c\n", type42->poly_approx_type); break;
				}

			save_myfprintf(fp,"%s%s%2.2d     Valid Frequency Units:                 ", blkt_id,FLD_PREF,9);
				switch (type42->valid_freq_units)
				{
				case 'A' : save_myfprintf(fp,"A [rad/sec]\n"); break;
				case 'B' : save_myfprintf(fp,"B [Hz]\n"); break;
				default  : save_myfprintf(fp,"%c\n",type42->valid_freq_units); break;
			}

			save_myfprintf(fp,"%s%s%2.2d     Lower Valid Frequency Bound:           %G\n",
					blkt_id,FLD_PREF,10,type42->lower_valid_freq);

			save_myfprintf(fp,"%s%s%2.2d     Upper Valid Frequency Bound:           %G\n",
					blkt_id,FLD_PREF,11,type42->upper_valid_freq);

			save_myfprintf(fp,"%s%s%2.2d     Lower Bound of Approximation:          %G\n",
					blkt_id,FLD_PREF,12,type42->lower_bound_approx);

			save_myfprintf(fp,"%s%s%2.2d     Upper Bound of Approximation:          %G\n",
					blkt_id,FLD_PREF,13,type42->upper_bound_approx);

			save_myfprintf(fp,"%s%s%2.2d     Maximum Absolute Error:                %G\n",
					blkt_id,FLD_PREF,14,type42->max_abs_error);

			save_myfprintf(fp,"%s%s%2.2d     Number of coefficients:                %d\n",
					blkt_id,FLD_PREF,15,type42->number_coefficients);

			save_myfprintf(fp,"%sPolynomial coefficients:\n",COM_STRT);

			save_myfprintf(fp,"%s  i, coefficient,  error\n",COM_STRT);
			for (i = 0; i < type42->number_coefficients; i++)
				save_myfprintf(fp,"%s%s%2.2d-%2.2d  %3d % E % E\n",
						blkt_id,FLD_PREF,16,17,i, 
						type42->coefficient[i].coefficient,
						type42->coefficient[i].error);


            save_myfprintf(fp,"%s\n",COM_STRT);

			break;
		}
	}

	if (type42 == NULL) return(0); else return(1);
}

int
old_find_type42(fp, code)
FILE *fp;
int code;
{
	struct type42 *type42;					/* looping vbl */
	int i;							/* counter */

	for (type42 = type42_head; type42 != NULL; type42 = type42->next)
	{
		if (type42->response_code == code)
		{
			if (fp == NULL) break;

			save_myfprintf (fp,"B042\n");
			save_myfprintf(fp,"Response Lookup Code:                  %d\n",
				type42->response_code);

			save_myfprintf(fp,"Response name:                         %s\n",
				type42->name ? type42->name : "(null)");

			save_myfprintf (fp, "Transfer function type:       ");
				switch (type42->transfer_fct_type)
				{
				case 'A' : save_myfprintf(fp,"         A [Laplace Transform (Rad/sec)]\n"); break;
				case 'B' : save_myfprintf(fp,"         B [Analog (Hz)]\n"); break;
				case 'C' : save_myfprintf(fp,"         C [Composite]\n"); break;
				case 'D' : save_myfprintf(fp,"         D [Digital (Z-transform)]\n"); break;
				case 'P' : save_myfprintf(fp,"         P [Polynomial]\n"); break;
				default  : save_myfprintf(fp,"         %c\n",type42->transfer_fct_type); break;
				}

			save_myfprintf (fp,"Response in units lookup:  %4d        ",
				type42->input_units_code);
			find_type34(fp,type42->input_units_code);

			save_myfprintf (fp,"Response out units lookup:  %4d       ",
				type42->output_units_code);
			find_type34(fp,type42->output_units_code);

			save_myfprintf(fp,"Polynomial Approximation Type:         ");
				switch (type42->poly_approx_type)
				{
				case 'M' : save_myfprintf(fp,"M [MacLaurin]\n"); break;
				default  : save_myfprintf(fp,"%c\n",type42->poly_approx_type); break;
				}

			save_myfprintf(fp,"Valid Frequency Units:                 ");
				switch (type42->valid_freq_units)
				{
				case 'A' : save_myfprintf(fp,"A [rad/sec]\n"); break;
				case 'B' : save_myfprintf(fp,"B [Hz]\n"); break;
				default  : save_myfprintf(fp,"%c\n",type42->valid_freq_units); break;
			}

			save_myfprintf(fp,"Lower Valid Frequency Bound:            %G\n",
				type42->lower_valid_freq);

			save_myfprintf(fp,"Upper Valid Frequency Bound:            %G\n",
				type42->upper_valid_freq);

			save_myfprintf(fp,"Lower Bound of Approximation:           %G\n",
				type42->lower_bound_approx);

			save_myfprintf(fp,"Upper Bound of Approximation:           %G\n",
				type42->upper_bound_approx);

			save_myfprintf(fp,"Maximum Absolute Error:                 %G\n",
				type42->max_abs_error);

			save_myfprintf (fp,"Number of coefficients:                %d\n",
				type42->number_coefficients);

			if( type42->number_coefficients != 0 )
			{
				save_myfprintf (fp,"Polynomial coefficients:\n");

				save_myfprintf (fp,"  i, coefficient, error\n");

				for (i = 0; i < type42->number_coefficients; i++)
					save_myfprintf(fp,"%03d % E % E\n",
					i, 
					type42->coefficient[i].coefficient,
					type42->coefficient[i].error);
			}

			save_myfprintf(fp,"\n");

			break;
		}
	}
	if (type42 == NULL) return(0); else return(1);
}
