/*===========================================================================*/
/* SEED reader     |            print_type44               |  station header */
/*===========================================================================*/
/*
	Name:		print_type44
	Purpose:	print the channel coefficients response table to standard 
				output
	Usage:		void print_type44 ();
				print_type44 ();
	Input:		none - uses information in globally-available structure
	Output:		none
	Externals:	type44_head - 1st entry in table; defined in structures.h, 
					allocated in globals.h
	Warnings:	none
	Errors:		none
	Called by:	print_response
	Calls to:	none
	Algorithm:	print the contents of the structure to the standard output.
	Notes:		The structure is a linked list; type44_head is the first member
				of the list
	Problems:	none known
	References:	Halbert et al, 1988; see main routine
	Language:	C, hopefully ANSI standard
	Author:		Dennis O'Neill
	Revisions:	07/15/88  Dennis O'Neill  Initial preliminary release 0.9
				11/21/88  Dennis O'Neill  Production release 1.0
				06/14/90  Sue Schoch      added response type field
				02/16/94  CL made printfs null-pointer protected
*/

#include "rdseed.h"
#include "resp_defs.h"

int find_type44(fp, code)
FILE *fp;
int code;
{
	struct type44 *type44;							/* looping vbl */
	int i;										/* counter */
	char *blkt_id="B044";						/* blockette id string */

	for (type44 = type44_head; type44 != NULL; type44 = type44->next)
	{
		if (type44->response_code == code)
		{
			if (fp == NULL) break;

			save_myfprintf (fp,"%s+               +-----------------------", COM_STRT);
			save_myfprintf (fp,"--------------------+                 +\n");
			save_myfprintf (fp,"%s+               |   Response (Coefficients), %5s ch %3s", COM_STRT,
					 current_station->station, current_channel->channel);
			save_myfprintf (fp,"   |                 +\n");
			save_myfprintf (fp,"%s+               +-----------------------", COM_STRT);
			save_myfprintf (fp,"--------------------+                 +\n");
			save_myfprintf (fp,"%s\n", COM_STRT);

			save_myfprintf (fp,"%s%s%2.2d     Response type:                         %c\n",
				blkt_id,FLD_PREF,5,type44->response_type);

			save_myfprintf (fp,"%s%s%2.2d     Response in units lookup:              ",
				blkt_id,FLD_PREF,6);

			find_type34(fp,type44->input_units_code);

			save_myfprintf (fp,"%s%s%2.2d     Response out units lookup:             ",
				blkt_id,FLD_PREF,7);
			find_type34(fp,type44->output_units_code);

			save_myfprintf (fp,"%s%s%2.2d     Number of numerators:                  %d\n",
				blkt_id,FLD_PREF,8,type44->number_numerators);

			save_myfprintf (fp,"%s%s%2.2d     Number of denominators:                %d\n",
				blkt_id,FLD_PREF,11,type44->number_denominators);

			save_myfprintf (fp,"%sNumerator coefficients:\n",COM_STRT);
			save_myfprintf (fp,"%s  i, coefficient,  error\n",COM_STRT);
			for (i = 0; i < type44->number_numerators; i++)
				save_myfprintf (fp,"%s%s%2.2d-%2.2d  %3d % E % E\n",blkt_id,FLD_PREF,9,10,i, 
						 type44->numerator[i].coefficient,type44->numerator[i].error);

			if (type44->number_denominators != 0)
			{
				save_myfprintf (fp,"%sDenominator coefficients:\n",COM_STRT);
				save_myfprintf (fp,"%s i, coefficient, error\n",COM_STRT);
				for (i = 0; i < type44->number_denominators; i++)
					save_myfprintf (fp,"%s%s%2.2d-%2.2d  %3d % E % E\n",blkt_id,FLD_PREF,12,13,
							 i,type44->denominator[i].coefficient,
							 type44->denominator[i].error);
			}
			save_myfprintf (fp,"%s\n",COM_STRT);
			break;
		}
	}
	if (type44 == NULL) return(0); else return(1);
}

int old_find_type44(fp, code)
FILE *fp;
int code;
{
	struct type44 *type44;							/* looping vbl */
	int i;										/* counter */

	for (type44 = type44_head; type44 != NULL; type44 = type44->next)
	{
		if (type44->response_code == code)
		{
			if (fp == NULL) break;

			save_myfprintf (fp,"B044\n");
			save_myfprintf (fp,"Response Lookup Code:                  %d\n",
				type44->response_code);

			save_myfprintf (fp,"Response name:                         %s\n",
				type44->name ? type44->name : "(null)");

			save_myfprintf (fp,"Response type:                         %c\n",
				type44->response_type);

			save_myfprintf (fp,"Response in units lookup: %4d         ",
				type44->input_units_code);

			find_type34(fp,type44->input_units_code);

			save_myfprintf (fp,"Response out units lookup: %4d        ",
				type44->output_units_code);
			find_type34(fp,type44->output_units_code);

			save_myfprintf (fp,"Number of numerators:                  %d\n",
				type44->number_numerators);

			save_myfprintf (fp,"Number of denominators:                %d\n",
				type44->number_denominators);

			save_myfprintf (fp,"Numerator coefficients:\n");
			save_myfprintf (fp,"  i, coefficient,  error\n");
			for (i = 0; i < type44->number_numerators; i++)
				save_myfprintf (fp,"%3d % E % E\n", i, 
				type44->numerator[i].coefficient, type44->numerator[i].error);

			if (type44->number_denominators != 0)
			{
				save_myfprintf (fp,"Denominator coefficients:\n");
				save_myfprintf (fp,"  i, coefficient,  error\n");
				for (i = 0; i < type44->number_denominators; i++)
					save_myfprintf (fp,"%3d % E % E\n", i, 
					type44->denominator[i].coefficient, type44->denominator[i].error);
			}
			save_myfprintf (fp,"\n");
			break;
		}
	}
	if (type44 == NULL) return(0); else return(1);
}
