/*===========================================================================*/
/* SEED reader     |              print_type30               |   abbrev dctnry */
/*===========================================================================*/
/*
	Name:		print_type30
	Purpose:	print the contents of the data format dictionary to standard 
				output
	Usage:		void print_type30 ();
				print_type30 ();
	Input:		none - uses information in globally-available structure
	Output:		none
	Externals:	type30_head - 1st entry in table; defined in structures.h, 
					allocated in globals.h
				type30 - defined in structures.h, allocated in globals.h
	Warnings:	none
	Errors:		none
	Called by:	print_abbrevdic
	Calls to:	none
	Algorithm:	print the contents of the structure to the standard output.
	Notes:		The structure is a linked list; type30_head is the first member
				of the list
	Problems:	none known
	References:	Halbert et al, 1988; see main routine
	Language:	C, hopefully ANSI standard
	Author:		Dennis O'Neill
	Revisions:	07/15/88  Dennis O'Neill  Initial preliminary release 0.9
				11/21/88  Dennis O'Neill  Production release 1.0
                02/17/93  CL    nullpointer protect save_myfprintfs
				10/13/95  TJM   prefix strings added to make consistent with RESP files
*/

#include "rdseed.h"
#include "resp_defs.h"

void print_type30 ()
{
	struct type30 *type30;							/* looping vbl */
	int i;										/* counter */
	char *blkt_id="B030";						/* blockette id string */

	if (type30_head != NULL)
	{
		save_myfprintf(outputfile,"%s+                  +--------------------",COM_STRT);
		save_myfprintf(outputfile,"-------------------+                  +\n");
		save_myfprintf(outputfile,"%s+------------------|        Data format ",COM_STRT);
		save_myfprintf(outputfile,"dictionary         |------------------+\n");
		save_myfprintf(outputfile,"%s+                  +--------------------",COM_STRT);
		save_myfprintf(outputfile,"-------------------+                  +\n");
		save_myfprintf(outputfile,"%s\n",COM_STRT);

		for (type30 = type30_head; type30 != NULL; type30 = type30->next)
		{
			/* report the values found in the blockette */
			save_myfprintf(outputfile,"%s%s%2.2d     Format name:                           %s\n",
					blkt_id,FLD_PREF,3,type30->name ? type30->name : "(null)");
			save_myfprintf(outputfile,"%s%s%2.2d     Format code:                           %d\n",
					blkt_id,FLD_PREF,4,type30->code);
			save_myfprintf(outputfile,"%s%s%2.2d     Data family:                           %d\n",
					blkt_id,FLD_PREF,5,type30->family);
			for (i = 0; i < type30->number_keys; i++) 
				save_myfprintf(outputfile,"%s%s%2.2d     Decoder key %03d:                       %s\n",
						blkt_id,FLD_PREF,7,i+1,type30->decoder_key[i] ? type30->decoder_key[i] : "(null)");
			save_myfprintf(outputfile,"%s\n",COM_STRT);
		}
	}
}
