/*===========================================================================*/
/* SEED reader     |              print_type34                |   abbrev dctnry */
/*===========================================================================*/
/*
	Name:		print_type34
	Purpose:	print the contents of the units dictionary to standard output
	Usage:		void print_type34 ();
				print_type34 ();
	Input:		none - uses information in globally-available structure
	Output:		none
	Externals:	type34_head - 1st entry in table; defined in structures.h, 
					allocated in globals.h
	Warnings:	none
	Errors:		none
	Called by:	print_abbrevdic
	Calls to:	none
	Algorithm:	print the contents of the structure to the standard output.
	Notes:		The structure is a linked list; type34_head is the first member
				of the list
	Problems:	none known
	References:	Halbert et al, 1988; see main routine
	Language:	C, hopefully ANSI standard
	Author:		Dennis O'Neill
	Revisions:	07/15/88  Dennis O'Neill  Initial preliminary release 0.9
				11/21/88  Dennis O'Neill  Production release 1.0
                02/17/93  CL    nullpointer protect save_myfprintfs
				10/13/95  TJM   prefix strings added to make consistent with RESP files
*/

#include "rdseed.h"
#include "resp_defs.h"

void print_type34 ()
{
	struct type34 *type34;							/* looping vbl */
	char *blkt_id="B034";						/* blockette id string */

	if (type34_head != NULL)
	{
		save_myfprintf(outputfile,"%s+                  +--------------------",COM_STRT);
		save_myfprintf(outputfile,"-------------------+                  +\n");
		save_myfprintf(outputfile,"%s+------------------|     Units abbreviat",COM_STRT);
		save_myfprintf(outputfile,"ion dictionary     |------------------+\n");
		save_myfprintf(outputfile,"%s+                  +--------------------",COM_STRT);
		save_myfprintf(outputfile,"-------------------+                  +\n");
		save_myfprintf(outputfile,"%s\n",COM_STRT);

		for (type34 = type34_head; type34 != NULL; type34 = type34->next)
		{
			save_myfprintf(outputfile,"%s%s%2.2d     Unit code:                             %d\n",
					blkt_id,FLD_PREF,3,type34->code);
			save_myfprintf(outputfile,"%s%s%2.2d     Unit name:                             %s\n",
					blkt_id,FLD_PREF,4,type34->name ? type34->name : "(null)");
			save_myfprintf(outputfile,"%s%s%2.2d     Unit description:                      %s\n",
					blkt_id,FLD_PREF,5,type34->description ? type34->description : "(null)");
			save_myfprintf(outputfile,"%s\n",COM_STRT);
		}
	}
}
