/*===========================================================================*/
/* SEED reader     |            print_type41               |  station header */
/*===========================================================================*/
/*
	Name:		print_type41
	Purpose:	print the channel coefficients response table to standard 
				output
	Usage:		void print_type41 ();
				print_type41 ();
	Input:		none - uses information in globally-available structure
	Output:		none
	Externals:	type41_head - 1st entry in table; defined in structures.h, 
					allocated in globals.h
	Warnings:	none
	Errors:		none
	Called by:	print_response
	Calls to:	none
	Algorithm:	print the contents of the structure to the standard output.
	Notes:		The structure is a linked list; type41_head is the first member
				of the list
	Problems:	none known
	References:	Halbert et al, 1988; see main routine
	Language:	C, hopefully ANSI standard
	Author:		Dennis O'Neill
	Revisions:	07/15/88  Dennis O'Neill  Initial preliminary release 0.9
				11/21/88  Dennis O'Neill  Production release 1.0
				06/14/90  Sue Schoch      added response type field
                02/17/93  CL    nullpointer protect save_myfprintfs
				10/13/95  TJM   prefix strings added to make consistent with RESP files
*/

#include "rdseed.h"
#include "resp_defs.h"

void print_type41()
{
	struct type41 *type41;							/* looping vbl */
	int i;										/* counter */
	char *blkt_id="B041";						/* blockette id string */

	if (type41_head != NULL)
	{

		save_myfprintf(outputfile,"%s+                  +--------------------",COM_STRT);
		save_myfprintf(outputfile,"-------------------+                  +\n");
		save_myfprintf(outputfile,"%s+------------------|  Response (Coefficients) Dictionary",
				COM_STRT);
		save_myfprintf(outputfile,"   |------------------+\n");
		save_myfprintf(outputfile,"%s+                  +--------------------",COM_STRT);
		save_myfprintf(outputfile,"-------------------+                  +\n");
		save_myfprintf(outputfile,"%s\n",COM_STRT);

	
		for (type41 = type41_head; type41 != NULL; type41 = type41->next)
		{
			save_myfprintf(outputfile,"%s%s%2.2d     Response Lookup Code:                  %d\n",
					blkt_id,FLD_PREF,3,type41->response_code);
			save_myfprintf(outputfile,"%s%s%2.2d     Response name:                         %s\n",
					blkt_id,FLD_PREF,4,type41->name ? type41->name : "(null)");
			save_myfprintf(outputfile,"%s%s%2.2d     Symmetry type:                         %c\n",
					blkt_id,FLD_PREF,5,type41->symmetry_code);
			save_myfprintf(outputfile,"%s%s%2.2d     Response in units lookup:  %4d        ",
					blkt_id,FLD_PREF,6,type41->input_units_code);
			find_type34(outputfile, type41->input_units_code);
			save_myfprintf(outputfile,"%s%s%2.2d     Response out units lookup: %4d        ",
					blkt_id,FLD_PREF,7,type41->output_units_code);
			find_type34(outputfile, type41->output_units_code);
			save_myfprintf(outputfile,"%s%s%2.2d     Number of numerators:                  %d\n",
					blkt_id,FLD_PREF,8,type41->number_numerators);
			save_myfprintf(outputfile,"%sNumerator coefficients:\n",COM_STRT);
			save_myfprintf(outputfile,"%s  i, coefficient\n",COM_STRT);
			for (i = 0; i < type41->number_numerators; i++)
				save_myfprintf(outputfile,"%s%s%2.2d     %3d % E\n",blkt_id,FLD_PREF,9,i, 
						type41->numerator[i]);
			save_myfprintf(outputfile,"%s\n",COM_STRT);
		}
	}
}
