/*===========================================================================*/
/* SEED reader     |            print_type42               |  station header */
/*===========================================================================*/
/*
	Name:		print_type42
	Purpose:	print the channel polynomial response table to standard 
				output
	Usage:		void print_type42 ();
				print_type42 ();
	Input:		none - uses information in globally-available structure
	Output:		none
	Externals:	type42_head - 1st entry in table; defined in structures.h, 
					allocated in globals.h
	Warnings:	none
	Errors:		none
	Called by:	print_response
	Calls to:	none
	Algorithm:	print the contents of the structure to the standard output.
	Notes:		The structure is a linked list; type42_head is the first member
				of the list
	Problems:	none known
	References:	Halbert et al, 1988; see main routine
	Language:	C, hopefully ANSI standard
	Author:		Stephane Zuzlewski
*/

#include "rdseed.h"
#include "resp_defs.h"

void print_type42()
{
	struct type42 *type42;			/* looping vbl */
	int i;					/* counter */
	char *blkt_id="B042";			/* blockette id string */

	if (type42_head != NULL)
	{

		save_myfprintf(outputfile,"%s+                  +--------------------",COM_STRT);
		save_myfprintf(outputfile,"-------------------+                  +\n");
		save_myfprintf(outputfile,"%s+------------------|   Response (Polynomial) Dictionary ",
				COM_STRT);
		save_myfprintf(outputfile,"   |------------------+\n");
		save_myfprintf(outputfile,"%s+                  +--------------------",COM_STRT);
		save_myfprintf(outputfile,"-------------------+                  +\n");
		save_myfprintf(outputfile,"%s\n",COM_STRT);

	
		for (type42 = type42_head; type42 != NULL; type42 = type42->next)
		{
			save_myfprintf(outputfile,"%s%s%2.2d     Response Lookup Code:                  %d\n",
					blkt_id,FLD_PREF,3,type42->response_code);

			save_myfprintf(outputfile,"%s%s%2.2d     Response name:                         %s\n",
					blkt_id,FLD_PREF,4,type42->name ? type42->name : "(null)");

			save_myfprintf (outputfile, "%s%s%2.2d     Transfer function type:       ",blkt_id,FLD_PREF,5);
				switch (type42->transfer_fct_type)
				{
				case 'A' : save_myfprintf(outputfile,"         A [Laplace Transform (Rad/sec)]\n"); break;
				case 'B' : save_myfprintf(outputfile,"         B [Analog (Hz)]\n"); break;
				case 'C' : save_myfprintf(outputfile,"         C [Composite]\n"); break;
				case 'D' : save_myfprintf(outputfile,"         D [Digital (Z-transform)]\n"); break;
				case 'P' : save_myfprintf(outputfile,"         P [Polynomial]\n"); break;
			/* 	default  : save_myfprintf(outputfile,"         %s\n",type42->transfer_fct_type ? (char *)type42->transfer_fct_type : "(null)"); break;
		*/
				default  : save_myfprintf(outputfile,"         %c\n",
						type42->transfer_fct_type); 
						break;
				}

			save_myfprintf(outputfile,"%s%s%2.2d     Response in units lookup:  %4d        ",
					blkt_id,FLD_PREF,6,type42->input_units_code);
			find_type34(outputfile, type42->input_units_code);

			save_myfprintf(outputfile,"%s%s%2.2d     Response out units lookup: %4d        ",
					blkt_id,FLD_PREF,7,type42->output_units_code);
			find_type34(outputfile, type42->output_units_code);

			save_myfprintf(outputfile,"%s%s%2.2d     Polynomial Approximation Type:         ", blkt_id,FLD_PREF,8);
				switch (type42->poly_approx_type)
				{
				case 'M' : save_myfprintf(outputfile,"M [MacLaurin]\n"); break;
				default  : save_myfprintf(outputfile,"%c\n", type42->poly_approx_type); break;
				}

			save_myfprintf(outputfile,"%s%s%2.2d     Valid Frequency Units:                 ", blkt_id,FLD_PREF,9);
				switch (type42->valid_freq_units)
				{
				case 'A' : save_myfprintf(outputfile,"A [rad/sec]\n"); break;
				case 'B' : save_myfprintf(outputfile,"B [Hz]\n"); break;
				default  : save_myfprintf(outputfile,"%c\n",type42->valid_freq_units); break;
			}

			save_myfprintf(outputfile,"%s%s%2.2d     Lower Valid Frequency Bound:           %G\n",
					blkt_id,FLD_PREF,10,type42->lower_valid_freq);

			save_myfprintf(outputfile,"%s%s%2.2d     Upper Valid Frequency Bound:           %G\n",
					blkt_id,FLD_PREF,11,type42->upper_valid_freq);

			save_myfprintf(outputfile,"%s%s%2.2d     Lower Bound of Approximation:          %G\n",
					blkt_id,FLD_PREF,12,type42->lower_bound_approx);

			save_myfprintf(outputfile,"%s%s%2.2d     Upper Bound of Approximation:          %G\n",
					blkt_id,FLD_PREF,13,type42->upper_bound_approx);

			save_myfprintf(outputfile,"%s%s%2.2d     Maximum Absolute Error:                %G\n",
					blkt_id,FLD_PREF,14,type42->max_abs_error);

			save_myfprintf(outputfile,"%s%s%2.2d     Number of coefficients:                %d\n",
					blkt_id,FLD_PREF,15,type42->number_coefficients);

			save_myfprintf(outputfile,"%sPolynomial coefficients:\n",COM_STRT);

			save_myfprintf(outputfile,"%s  i, coefficient,  error\n",COM_STRT);
			for (i = 0; i < type42->number_coefficients; i++)
				save_myfprintf(outputfile,"%s%s%2.2d-%2.2d  %3d % E % E\n",
						blkt_id,FLD_PREF,16,17,i, 
						type42->coefficient[i].coefficient,
						type42->coefficient[i].error);

			save_myfprintf(outputfile,"%s\n",COM_STRT);
		}
	}
}
