/*===========================================================================*/
/* SEED reader     |            print_type44               |  station header */
/*===========================================================================*/
/*
	Name:		print_type44
	Purpose:	print the channel coefficients response table to standard 
				output
	Usage:		void print_type44 ();
				print_type44 ();
	Input:		none - uses information in globally-available structure
	Output:		none
	Externals:	type44_head - 1st entry in table; defined in structures.h, 
					allocated in globals.h
	Warnings:	none
	Errors:		none
	Called by:	print_response
	Calls to:	none
	Algorithm:	print the contents of the structure to the standard output.
	Notes:		The structure is a linked list; type44_head is the first member
				of the list
	Problems:	none known
	References:	Halbert et al, 1988; see main routine
	Language:	C, hopefully ANSI standard
	Author:		Dennis O'Neill
	Revisions:	07/15/88  Dennis O'Neill  Initial preliminary release 0.9
				11/21/88  Dennis O'Neill  Production release 1.0
				06/14/90  Sue Schoch      added response type field
                02/17/93  CL    nullpointer protect save_myfprintfs
				10/13/95  TJM   prefix strings added to make consistent with RESP files
*/

#include "rdseed.h"
#include "resp_defs.h"

void print_type44()
{
	struct type44 *type44;							/* looping vbl */
	int i;										/* counter */
	char *blkt_id="B044";						/* blockette id string */

	if (type44_head != NULL)
	{

		save_myfprintf(outputfile,"%s+                  +--------------------",COM_STRT);
		save_myfprintf(outputfile,"-------------------+                  +\n");
		save_myfprintf(outputfile,"%s+------------------|  Response (Coefficients) Dictionary",
				COM_STRT);
		save_myfprintf(outputfile,"   |------------------+\n");
		save_myfprintf(outputfile,"%s+                  +--------------------",COM_STRT);
		save_myfprintf(outputfile,"-------------------+                  +\n");
		save_myfprintf(outputfile,"%s\n",COM_STRT);

	
		for (type44 = type44_head; type44 != NULL; type44 = type44->next)
		{
			save_myfprintf(outputfile,"%s%s%2.2d     Response Lookup Code:                  %d\n",
					blkt_id,FLD_PREF,3,type44->response_code);
			save_myfprintf(outputfile,"%s%s%2.2d     Response name:                         %s\n",
					blkt_id,FLD_PREF,4,type44->name ? type44->name : "(null)");
			save_myfprintf(outputfile,"%s%s%2.2d     Response type:                         %c\n",
					blkt_id,FLD_PREF,5,type44->response_type);
			save_myfprintf(outputfile,"%s%s%2.2d     Response in units lookup:  %4d        ",
					blkt_id,FLD_PREF,6,type44->input_units_code);
			find_type34(outputfile, type44->input_units_code);
			save_myfprintf(outputfile,"%s%s%2.2d     Response out units lookup: %4d        ",
					blkt_id,FLD_PREF,7,type44->output_units_code);
			find_type34(outputfile, type44->output_units_code);
			save_myfprintf(outputfile,"%s%s%2.2d     Number of numerators:                  %d\n",
					blkt_id,FLD_PREF,8,type44->number_numerators);
			save_myfprintf(outputfile,"%s%s%2.2d     Number of denominators:                %d\n",
					blkt_id,FLD_PREF,11,type44->number_denominators);
			save_myfprintf(outputfile,"%sNumerator coefficients:\n",COM_STRT);
			save_myfprintf(outputfile,"%s  i, coefficient,  error\n",COM_STRT);
			for (i = 0; i < type44->number_numerators; i++)
				save_myfprintf(outputfile,"%s%s%2.2d-%2.2d  %3d % E % E\n",
						blkt_id,FLD_PREF,9,10,i, 
						type44->numerator[i].coefficient,type44->numerator[i].error);
			if (type44->number_denominators != 0)
			{
				save_myfprintf(outputfile,"%sDenominator coefficients:\n",COM_STRT);
				save_myfprintf(outputfile,"%s  i, coefficient,  error\n",COM_STRT);
				for (i = 0; i < type44->number_denominators; i++)
					save_myfprintf(outputfile,"%%s%s%2.2d-%2.2d  3d % E % E\n",
							blkt_id,FLD_PREF,12,13,i, 
							type44->denominator[i].coefficient,
							type44->denominator[i].error);
			}
			save_myfprintf(outputfile,"%s\n",COM_STRT);
		}
	}
}
