/*===========================================================================*/
/* SEED reader     |              print_type53               |  station header */
/*===========================================================================*/
/*
	Name:		print_type53
	Purpose:	print channel poles and zeroes response table to standard 
				output
	Usage:		void print_type53 ();
				print_type53 ();
	Input:		none - uses information in globally-available structure
	Output:		none
	Externals:	type53_head - 1st entry in table; defined in structures.h, 
					allocated in globals.h
	Warnings:	none
	Errors:		none
	Called by:	print_response
	Calls to:	none
	Algorithm:	print the contents of the structure to the standard output.
	Notes:		The structure is a linked list; type53_head is the first member
				of the list
	Problems:	none known
	References:	Halbert et al, 1988; see main routine
	Language:	C, hopefully ANSI standard
	Author:		Dennis O'Neill
	Revisions:	07/15/88  Dennis O'Neill  Initial preliminary release 0.9
				11/21/88  Dennis O'Neill  Production release 1.0
                02/17/93  CL    nullpointer protect save_myfprintfs
*/

#include "rdseed.h"
#include "resp_defs.h"

void print_type53 (fp,type53_head)
FILE *fp;
struct type53 *type53_head;
{
	struct type53 *type53;						/* looping vbl */
	int i;										/* counter */
	char *blkt_id="B053";						/* blockette id string */

	save_myfprintf (fp,"%s+               +-----------------------",COM_STRT);
	save_myfprintf (fp,"---------------------+                +\n");
	save_myfprintf (fp,"%s+               |   Response (Poles & Zeros), %5s ch %3s",COM_STRT,
		current_station->station, current_channel->channel);
	save_myfprintf (fp,"   |                +\n");
	save_myfprintf (fp,"%s+               +-----------------------",COM_STRT);
	save_myfprintf (fp,"---------------------+                +\n");
	save_myfprintf (fp,"%s\n",COM_STRT);

	for (type53 = type53_head; type53 != NULL; type53 = type53->next)
	{
	    save_myfprintf (fp, "%s%s%2.2d     Transfer function type:       ",blkt_id,FLD_PREF,3);
		switch (*(type53->transfer))
		{
			case 'A' : save_myfprintf(fp,"         A [Laplace Transform (Rad/sec)]\n"); break;
			case 'B' : save_myfprintf(fp,"         B [Analog (Hz)]\n"); break;
			case 'C' : save_myfprintf(fp,"         C [Composite]\n"); break;
			case 'D' : save_myfprintf(fp,"         D [Digital (Z-transform)]\n"); break;
			default  : save_myfprintf(fp,"         %s\n",type53->transfer ? type53->transfer : "(null)"); break;
		}
		save_myfprintf (fp,"%s%s%2.2d     Stage sequence number:                 %d\n",
			blkt_id,FLD_PREF,4,type53->stage);
		save_myfprintf (fp,"%s%s%2.2d     Response in units lookup:              ",
			blkt_id,FLD_PREF,5);
		find_type34(fp,type53->input_units_code);
		save_myfprintf (fp,"%s%s%2.2d     Response out units lookup:             ",
			blkt_id,FLD_PREF,6);
		find_type34(fp,type53->output_units_code);
		save_myfprintf (fp,"%s%s%2.2d     A0 normalization factor:               %G\n",
			blkt_id,FLD_PREF,7,type53->ao_norm);
		save_myfprintf (fp,"%s%s%2.2d     Normalization frequency:               %G\n",
			blkt_id,FLD_PREF,8,type53->norm_freq);
		save_myfprintf (fp,"%s%s%2.2d     Number of zeroes:                      %d\n",
			blkt_id,FLD_PREF,9,type53->number_zeroes);
		save_myfprintf (fp,"%s%s%2.2d     Number of poles:                       %d\n",
			blkt_id,FLD_PREF,14,type53->number_poles);
		save_myfprintf (fp,"%sComplex zeroes:\n", COM_STRT);
		save_myfprintf (fp,"%s  i  real          imag          real_error    imag_error\n", COM_STRT);
		for (i = 0; i < type53->number_zeroes; i++)
			save_myfprintf (fp,"%s%s%2.2d-%2.2d  %3d % E % E % E % E\n", 
			blkt_id,FLD_PREF,10,13,i,
			type53->zero[i].real, 
			type53->zero[i].imag,
			type53->zero[i].real_error, 
			type53->zero[i].imag_error);
		save_myfprintf (fp,"%sComplex poles:\n", COM_STRT);
		save_myfprintf (fp,"%s  i  real          imag          real_error    imag_error\n", COM_STRT);
		for (i = 0; i < type53->number_poles; i++)
			save_myfprintf (fp,"%s%s%2.2d-%2.2d  %3d % E % E % E % E\n", 
			blkt_id,FLD_PREF,15,18,i,
			type53->pole[i].real, 
			type53->pole[i].imag,
			type53->pole[i].real_error, 
			type53->pole[i].imag_error);
		save_myfprintf (fp,"%s\n", COM_STRT);
	}
}

void old_print_type53 (fp,type53_head)
FILE *fp;
struct type53 *type53_head;
{
	struct type53 *type53;							/* looping vbl */
	int i;										/* counter */

	save_myfprintf (fp,"+                  +--------------------");
	save_myfprintf (fp,"-------------------+                  +\n");
	save_myfprintf (fp,"+                  |   Instrument response, %5s ch %3s",
		current_station->station, current_channel->channel);
	save_myfprintf (fp,"   |                  +\n");
	save_myfprintf (fp,"+                  +--------------------");
	save_myfprintf (fp,"-------------------+                  +\n");
	save_myfprintf (fp,"\n");

	save_myfprintf (fp,"Response type:                         Poles and zeroes\n");

	for (type53 = type53_head; type53 != NULL; type53 = type53->next)
	{
		switch (*(type53->transfer))
		{
			case 'A' : save_myfprintf (fp,"Transfer function type:                 Laplace Transform (Rad/sec)\n"); break;
			case 'B' : save_myfprintf (fp,"Transfer function type:                 Analog (Hz)\n"); break;
			case 'C' : save_myfprintf (fp,"Transfer function type:                 Composite\n"); break;
			case 'D' : save_myfprintf (fp,"Transfer function type:                 Digital (Z-transform)\n"); break;
			default  : save_myfprintf (fp,"Transfer function type:                %s\n", 
									type53->transfer ? type53->transfer : "(null)"); break;
		}
		save_myfprintf (fp,"Stage sequence number:                 %d\n",
			type53->stage);
		save_myfprintf (fp,"Response in units lookup:  %4d        ",
			type53->input_units_code);
		find_type34(fp,type53->input_units_code);
		save_myfprintf (fp,"Response out units lookup: %4d        ",
			type53->output_units_code);
		find_type34(fp,type53->output_units_code);
		save_myfprintf (fp,"AO normalization factor:               %G\n",
			type53->ao_norm);
		save_myfprintf (fp,"Normalization frequency:               %G\n",
			type53->norm_freq);
		save_myfprintf (fp,"Number of zeroes:                      %d\n",
			type53->number_zeroes);
		save_myfprintf (fp,"Number of poles:                       %d\n",
			type53->number_poles);
		save_myfprintf (fp,"Complex zeroes:\n");
		save_myfprintf (fp,"  i  real          imag          real_error    imag_error\n");
		for (i = 0; i < type53->number_zeroes; i++)
			save_myfprintf (fp,"%3d % E % E % E % E\n", i, 
			type53->zero[i].real, 
			type53->zero[i].imag,
			type53->zero[i].real_error, 
			type53->zero[i].imag_error);
		save_myfprintf (fp,"Complex poles:\n");
		save_myfprintf (fp,"  i  real          imag          real_error    imag_error\n");
		for (i = 0; i < type53->number_poles; i++)
			save_myfprintf (fp,"%3d % E % E % E % E\n", i, 
			type53->pole[i].real, 
			type53->pole[i].imag,
			type53->pole[i].real_error, 
			type53->pole[i].imag_error);
		save_myfprintf (fp,"\n");
	}
}
