/*===========================================================================*/
/* SEED reader     |             print_type74              |     time header */
/*===========================================================================*/
/*
	Name:		print_type74
	Purpose:	print the time series index table to the standard output
	Usage:		void print_type74 ();
				print_type74 ();
	Input:		none - uses information in globally-available structure
	Output:		none
	Externals:	type74_head - 1st entry in table; defined in structures.h, 
					allocated in globals.h
	Warnings:	none
	Errors:		none
	Called by:	print_timeh
	Calls to:	none
	Algorithm:	print the contents of the structure to the standard output.
	Notes:		The structure is a linked list; type74_head is the first member
				of the list
	Problems:	none known
	References:	Halbert et al, 1988; see main routine
	Language:	C, hopefully ANSI standard
	Author:		Dennis O'Neill
	Revisions:	08/29/89  Dennis O'Neill  Initial version
				04/26/93  Allen Nance     added field 16 for v2.3
                02/17/93  CL    nullpointer protect save_myfprintfs
				10/13/95  TJM   prefix strings added to make consistent with RESP files
*/

#include "rdseed.h"
#include "resp_defs.h"

void print_type74 ()
{
	struct type74 *type74;						/* looping vbl */
	char *blkt_id="B074";						/* blockette id string */

	if (type74_head != NULL)
	{

		/* print column headings for time index to available waveforms */
		save_myfprintf(outputfile,"%sSta   ",COM_STRT);
		save_myfprintf(outputfile,"Loc ");
		save_myfprintf(outputfile,"Chn ");
		if (type10.version >= 2.3)
			save_myfprintf(outputfile,"Net ");
		save_myfprintf(outputfile,"Start date and time    ");
		save_myfprintf(outputfile,"Record ");
		save_myfprintf(outputfile,"Sub ");
		save_myfprintf(outputfile,"End date and time      ");
		save_myfprintf(outputfile,"Record ");
		save_myfprintf(outputfile,"Sub ");
		save_myfprintf(outputfile,"Accel\n");

		for (type74 = type74_head; type74 != NULL; type74 = type74->next)
		{
			save_myfprintf(outputfile,"%s%s%2.2d-%2.2d      %-5.5s ",
					blkt_id,FLD_PREF,3,16,
					type74->station ? type74->station : "     ");

			save_myfprintf(outputfile,"%-2.2s  ", 
					type74->location ? type74->location : "  ");

			save_myfprintf(outputfile,"%-3.3s ",  
					type74->channel ? type74->channel : "   ");

			save_myfprintf(outputfile,"%-2.2s  ",  
					type74->network_code ? type74->network_code : "  ");

			save_myfprintf(outputfile,"%-22.22s ", 
					type74->starttime ? type74->starttime : "(null)");

			save_myfprintf(outputfile,"%-6ld ", type74->start_index);

			save_myfprintf(outputfile,"%-2d  ", type74->start_subindex);

			save_myfprintf(outputfile,"%-22.22s ", 
					type74->endtime ? type74->endtime : "(null)");

			save_myfprintf(outputfile,"%-6ld ", type74->end_index);
			save_myfprintf(outputfile,"%-2d  ", type74->end_subindex);
			save_myfprintf(outputfile,"%-2d\n" , type74->number_accelerators);

/*
			for (i = 0; i < type74->number_accelerators; i++)
			{
				
				if (strlen (type74->accelerator[i].index) != 0)
				{
					save_myfprintf(outputfile,"%6ld  %-22s  %2d\n",
					type74->accelerator[i].index,
					type74->accelerator[i].time,
					type74->accelerator[i].subindex);
				}
			}
*/
		}
	}
	save_myfprintf(outputfile,"%s\n",COM_STRT);
}
